@@ -2,8 +2,8 @@
 
 #  ************************** Copyrights and license ***************************
 #
-# This file is part of gcovr 7.0, a parsing and reporting tool for gcov.
-# https://gcovr.com/en/stable
+# This file is part of gcovr 8.2, a parsing and reporting tool for gcov.
+# https://gcovr.com/en/8.2
 #
 # _____________________________________________________________________________
 #
@@ -17,5 +17,13 @@
 #
 # ****************************************************************************
 
-JSON_FORMAT_VERSION = "0.6"
-JSON_SUMMARY_FORMAT_VERSION = "0.5"
+JSON_FORMAT_VERSION = (
+    # BEGIN version
+    "0.10"
+    # END version
+)
+JSON_SUMMARY_FORMAT_VERSION = (
+    # BEGIN summary version
+    "0.6"
+    # END summary version
+)
